summaryrefslogtreecommitdiffstats
path: root/lib/kformula/phantomelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/phantomelement.h')
-rw-r--r--lib/kformula/phantomelement.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/kformula/phantomelement.h b/lib/kformula/phantomelement.h
index 01880d7b..885a9651 100644
--- a/lib/kformula/phantomelement.h
+++ b/lib/kformula/phantomelement.h
@@ -27,22 +27,22 @@ KFORMULA_NAMESPACE_BEGIN
class PhantomElement : public SequenceElement {
typedef SequenceElement inherited;
public:
- PhantomElement( BasicElement* parent = 0 );
+ PhantomElement( BasicElement* tqparent = 0 );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
private:
- virtual QString getElementName() const { return "mphantom"; }
+ virtual TQString getElementName() const { return "mphantom"; }
};
@@ -27,22 +27,22 @@ KFORMULA_NAMESPACE_BEGIN
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/